Management Realms
=================

.. contents:: :local:

--------------

ManagementRealm
---------------

* :class:`cfxdb.mrealm.ManagementRealm`
* :class:`cfxdb.globalschema.ManagementRealms`
* :class:`cfxdb.globalschema.IndexManagementRealmByName`

-------

.. autoclass:: cfxdb.mrealm.ManagementRealm
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.ManagementRealms
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexManagementRealmByName
    :members:
    :show-inheritance:


Node
----

* :class:`cfxdb.mrealm.Node`
* :class:`cfxdb.globalschema.Nodes`
* :class:`cfxdb.globalschema.IndexNodesByPubkey`
* :class:`cfxdb.globalschema.IndexNodesByAuthid`
* :class:`cfxdb.usage.MasterNodeUsage`
* :class:`cfxdb.globalschema.UsageRecords`

-------

.. autoclass:: cfxdb.mrealm.Node
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.Nodes
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexNodesByPubkey
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.IndexNodesByAuthid
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.usage.MasterNodeUsage
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.globalschema.UsageRecords
    :members:
    :show-inheritance:
